@@ -47,7 +47,7 @@ class RelationExtractionVisualizer:
         with open('label_colors/entity_color.json', 'r', encoding='utf-8') as f_:
             self.entity_color_dict = json.load(f_)
             self.entity_color_dict = dict((k.lower(), v) for k, v in self.entity_color_dict.items())
-            self.font_path = 'IBMPlexSans-Regular.ttf'
+            self.font_path = 'fonts/IBMPlexSans-Regular.ttf'
             self.main_font = 'IBMPlexSans'
 
     def __get_color(self, l):
